==> vss-ui-4.141.4.tgz: package/Components/Accordion/Accordion.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { ActionButton } from "OfficeFabric/Button";
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssIcon } from '../../VssIcon';
var Accordion = /** @class */ (function (_super) {
    tslib_1.__extends(Accordion, _super);
    function Accordion(props) {
        var _this = _super.call(this, props) || this;
        var expandedDictionary = {};
        for (var _i = 0, _a = props.items; _i < _a.length; _i++) {
            var i = _a[_i];
            expandedDictionary[i.key] = props.initiallyExpandAll === true;
        }
        _this.state = {
            expandedDictionary: expandedDictionary
        };
        return _this;
    }
    Accordion.prototype.expand = function (itemKey) {
        var expandedDictionary = this.state.expandedDictionary;
        if (!expandedDictionary[itemKey]) {
            this.toggleExpand(itemKey);
        }
    };
    Accordion.prototype.collapse = function (itemKey) {
        var expandedDictionary = this.state.expandedDictionary;
        if (expandedDictionary[itemKey]) {
            this.toggleExpand(itemKey);
        }
    };
    Accordion.prototype.render = function () {
        return React.createElement("div", { className: css("accordion-root", this.props.className), role: "tablist" }, this.renderItems());
    };
    Accordion.prototype.renderItems = function () {
        var items = this.props.items;
        var elements = [];
        for (var i = 0; i < items.length; i++) {
            elements.push(this.renderItem(items[i], i));
        }
        return elements;
    };
    Accordion.prototype.renderItem = function (item, index) {
        var expandedDictionary = this.state.expandedDictionary;
        return React.createElement("div", { className: "accordion-item", key: item.key },
            React.createElement(ActionButton, { onClick: this.toggleExpand.bind(this, item.key), className: "accordion-header", role: "tab", "aria-expanded": expandedDictionary[item.key], "aria-setsize": this.props.items.length, "aria-posinset": index + 1 },
                React.createElement(VssIcon, { iconName: expandedDictionary[item.key] ? "ChevronDown" : "ChevronRight", iconType: 0 /* fabric */, className: "accordion-chevron" }),
                item.title || item.key),
            React.createElement("div", { className: css("accordion-content", { "hidden": !expandedDictionary[item.key] }) }, item.onRenderContent()));
    };
    Accordion.prototype.toggleExpand = function (key) {
        var expandedDictionary = this.state.expandedDictionary;
        expandedDictionary[key] = !expandedDictionary[key];
        if (this.props.onItemChanged) {
            this.props.onItemChanged(key, expandedDictionary[key]);
        }
        this.forceUpdate();
    };
    return Accordion;
}(BaseComponent));
export { Accordion };

==> vss-ui-4.142.1.tgz: package/Components/Accordion/Accordion.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { Button } from '../../Button';
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssIcon } from '../../VssIcon';
var Accordion = /** @class */ (function (_super) {
    tslib_1.__extends(Accordion, _super);
    function Accordion(props) {
        var _this = _super.call(this, props) || this;
        var expandedDictionary = {};
        for (var _i = 0, _a = props.items; _i < _a.length; _i++) {
            var i = _a[_i];
            expandedDictionary[i.key] = props.initiallyExpandAll === true;
        }
        _this.state = {
            expandedDictionary: expandedDictionary
        };
        return _this;
    }
    Accordion.prototype.expand = function (itemKey) {
        var expandedDictionary = this.state.expandedDictionary;
        if (!expandedDictionary[itemKey]) {
            this.toggleExpand(itemKey);
        }
    };
    Accordion.prototype.collapse = function (itemKey) {
        var expandedDictionary = this.state.expandedDictionary;
        if (expandedDictionary[itemKey]) {
            this.toggleExpand(itemKey);
        }
    };
    Accordion.prototype.render = function () {
        return React.createElement("div", { className: css("accordion-root", this.props.className), role: "tablist" }, this.renderItems());
    };
    Accordion.prototype.renderItems = function () {
        var items = this.props.items;
        var elements = [];
        for (var i = 0; i < items.length; i++) {
            elements.push(this.renderItem(items[i], i));
        }
        return elements;
    };
    Accordion.prototype.renderItem = function (item, index) {
        var expandedDictionary = this.state.expandedDictionary;
        return React.createElement("div", { className: "accordion-item", key: item.key },
            React.createElement(Button, { subtle: true, onClick: this.toggleExpand.bind(this, item.key), className: "accordion-header", role: "tab", ariaExpanded: expandedDictionary[item.key], ariaSetSize: this.props.items.length, ariaPosInSet: index + 1 },
                React.createElement(VssIcon, { iconName: expandedDictionary[item.key] ? "ChevronDown" : "ChevronRight", iconType: 0 /* fabric */, className: "accordion-chevron" }),
                item.title || item.key),
            React.createElement("div", { className: css("accordion-content", { "hidden": !expandedDictionary[item.key] }) }, item.onRenderContent()));
    };
    Accordion.prototype.toggleExpand = function (key) {
        var expandedDictionary = this.state.expandedDictionary;
        expandedDictionary[key] = !expandedDictionary[key];
        if (this.props.onItemChanged) {
            this.props.onItemChanged(key, expandedDictionary[key]);
        }
        this.forceUpdate();
    };
    return Accordion;
}(BaseComponent));
export { Accordion };
